/***************************************************************************
 *   Copyright (C) 2001 by Rick L. Vinyard, Jr.                            *
 *   rvinyard@cs.nmsu.edu                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Lesser General Public License as        *
 *   published by the Free Software Foundation version 2.1.                *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA              *
 ***************************************************************************/
#ifndef CONEXUSMMHOSTPORTENTRY_H
#define CONEXUSMMHOSTPORTENTRY_H

#include <gtkmm.h>

#include <conexusmm/hostentry.h>
#include <conexusmm/portentry.h>

namespace ConexusGtk {

/**
@author Rick L Vinyard Jr
*/
class HostPortEntry : public Gtk::Table
{
public:
  typedef enum Layout { VERTICAL, HORIZONTAL };
    HostPortEntry(Layout layout = VERTICAL);

    ~HostPortEntry();

    HostEntry& host_entry();
    PortEntry& port_entry();

    std::string hostname();
    void set_hostname(std::string);

    uint32_t port();
    void set_port(uint32_t p);

    void connect(Conexus::IPv4::Address& address);
    void connect(Conexus::IPv6::Address& address);
    void disconnect(Conexus::IPv4::Address& address);
    void disconnect(Conexus::IPv6::Address& address);

    sigc::signal<void, bool> signal_host_changed();
    sigc::signal<void> signal_port_changed();

    Layout layout();
    void set_layout(Layout layout);
    
  protected:
    HostEntry m_host;
    PortEntry m_port;
    Gtk::Alignment m_host_alignment, m_port_alignment;
    Layout m_layout;
    
    void setup_widget();
};

}

#endif
